@@ -96,22 +96,25 @@ class DataBase():
                     z += ' ({}) '.format(type(v).__name__)
                 z += ' [{}] '.format(', '.join(v.dims))
                 if v.is_loaded():
-                    z += ', (loaded)'
+                    z += '  (loaded)'
                 s.append(z)
             s.append('')
-        s.append("Data available: \n{}".format(repr(self.avail)))
+        s.append("Data available: ")
+        s.append('\n'.join(repr(self.avail).split('\n')[1:]))
         s.append('')
 
         if self.loaded.is_empty():
-            s.append('Data not loaded')
+            s.append('No data loaded')
         else:
-            s.append('Data loaded: \n{}'.format(repr(self.loaded)))
+            s.append("Data loaded: ")
+            s.append('\n'.join(repr(self.loaded).split('\n')[1:]))
         s.append('')
 
         if self.selected.is_empty():
             s.append('No data selected')
         else:
-            s.append('Data selected: \n{}'.format(repr(self.selected)))
+            s.append("Data selected: ")
+            s.append('\n'.join(repr(self.selected).split('\n')[1:]))
         s.append('')
 
         return '\n'.join(s)
@@ -669,8 +672,7 @@ def guess_dimensions(db: 'DataDisk', var: str):
 
         if warn:
             log.warning(("'%s' dimension is shared, but not present in the "
-                         "guess for variable '%s' (%s) "
-                         "something might be wrong"),
+                         "guess for variable '%s' (%s)"),
                         d, var, dims)
 
     return dims
